@@ -1,10 +1,11 @@
 #' Export a 'Raven' selection for all sound files in a folder
 #' 
 #' \code{exp_empty_sels} exports a 'Raven' selection data in .txt format that includes empty selections for all sound files in a folder.
-#' @usage exp_empty_sels(path = NULL, file.name = NULL, pb = TRUE)
+#' @usage exp_empty_sels(path = NULL, file.name = NULL, sound.files = NULL, pb = TRUE)
 #' @param path A character string indicating the path of the directory in which to look for sound files.
 #' If not provided (default) the function will use the current working directory.
 #' @param file.name Name of the output .txt file. If \code{NULL} then the folder name is used instead.
+#' @param sound.files character vector indicating the sound files that will be included. If \code{NULL} (default) then all .wav files in the working directory (or 'path') will be included.
 #' @param pb Logical argument to control progress bar. Default is \code{TRUE}.
 #' @return The function saves a selection table in '.txt' format that can be 
 #' directly opened in Raven.
@@ -19,6 +20,7 @@
 #' 
 #' # Load data
 #' library(NatureSounds)
+#' library(warbleR)
 #' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4", "lbh_selec_table"))
 #' 
 #' ## Export a single selection table including multiple files
@@ -38,15 +40,16 @@
 #' # export with file name
 #' exp_empty_sels(file.name = "Phaethornis.longirostris", path = tempdir())
 #' 
-#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
+#' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
 #last modification on oct-12-2018
 
-exp_empty_sels <- function(path = NULL, file.name = NULL, pb = TRUE){
+exp_empty_sels <- function(path = NULL, file.name = NULL, sound.files = NULL, pb = TRUE){
   
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
-    if (!dir.exists(path)) stop("'path' provided does not exist") 
-  
+    if (!dir.exists(path)) stop("'path' provided does not exist") else
+      path <- normalizePath(path)
+    
   # create a selection table for each sound file
   st <- warbleR::selection_table(whole.recs = TRUE, pb = FALSE, path = path)
   
@@ -56,6 +59,12 @@ exp_empty_sels <- function(path = NULL, file.name = NULL, pb = TRUE){
   st$bottom.freq <- 1
   st$selec <- 1:nrow(st)
   
+  # include only "sound.files"
+  if (!is.null(sound.files))
+    # check if sound files are found in st
+    if (!all(sound.files %in% st$sound.files)) stop("not all 'sound.files' were found") else
+      st <- st[st$sound.files %in% sound.files, ]
+    
   # add an extra column with sound file names
   st$Rraven.labels <- st$sound.files
   
